@@ -1,7 +1,7 @@
 extern crate pyroscope;
 
 use pyroscope::{PyroscopeAgent, Result};
-use pyroscope_pprofrs::{Pprof, PprofConfig};
+use pyroscope_pprofrs::{pprof_backend, PprofConfig};
 use std::hash::{Hash, Hasher};
 
 fn hash_rounds1(n: u64) -> u64 {
@@ -34,13 +34,20 @@ fn hash_rounds2(n: u64) -> u64 {
 
 #[tokio::main]
 async fn main() -> Result<()> {
-    let mut agent = PyroscopeAgent::builder("http://localhost:4040", "example.async")
-        .backend(Pprof::new(PprofConfig::new().sample_rate(100)))
+    let agent = PyroscopeAgent::builder("http://localhost:4040", "example.async")
+        .backend(pprof_backend(PprofConfig::new().sample_rate(100)))
         .tags([("TagA", "ValueA"), ("TagB", "ValueB")].to_vec())
         .build()?;
 
+    // Show start time
+    let start = std::time::SystemTime::now()
+        .duration_since(std::time::UNIX_EPOCH)
+        .unwrap()
+        .as_secs();
+    println!("Start Time: {}", start);
+
     // Start Agent
-    agent.start()?;
+    let agent_running = agent.start()?;
 
     tokio::task::spawn(async {
         let n = hash_rounds1(300_000);
@@ -57,7 +64,17 @@ async fn main() -> Result<()> {
     .unwrap();
 
     // Stop Agent
-    agent.stop()?;
+    let agent_ready = agent_running.stop()?;
+
+    // Shutdown the Agent
+    agent_ready.shutdown();
+
+    // Show program exit time
+    let exit = std::time::SystemTime::now()
+        .duration_since(std::time::UNIX_EPOCH)
+        .unwrap()
+        .as_secs();
+    println!("Exit Time: {}", exit);
 
     Ok(())
 }
